<?php
/*
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many individuals
 * and is licensed under the MIT license.
 */

namespace LmcRbacMvcTest\Role;

use Laminas\ServiceManager\ServiceManager;
use LmcRbacMvc\Role\RoleProviderPluginManager;

/**
 * @covers \LmcRbacMvc\Role\RoleProviderPluginManager
 */
class RoleProviderPluginManagerTest extends \PHPUnit\Framework\TestCase
{
    public function testValidationOfPluginSucceedsIfRoleProviderInterfaceIsImplemented()
    {
        $pluginMock    = $this->createMock('LmcRbacMvc\Role\RoleProviderInterface');
        $pluginManager = new RoleProviderPluginManager(new ServiceManager());

        $this->assertNull($pluginManager->validatePlugin($pluginMock));
    }

    public function testValidationOfPluginFailsIfRoleProviderInterfaceIsNotImplemented()
    {
        $this->expectException('LmcRbacMvc\Exception\RuntimeException');

        $pluginManager  = new RoleProviderPluginManager(new ServiceManager());
        $pluginManager->get('stdClass', []);
    }
}
